/*
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * Autor:Enrique Mengíbar Vázquez
 * Fecha: Enero 2012 
 * 
 * Description: Describe una noticia, se usa en el conjunto de clases del paquete basededatos para simular 
 * una BD sin persistencia compuesta por noticias y comentarios. 
 * la relación entre noticias y comentarios es uno a muchos
 * 
 */

package org.sofp.test.basededatos;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

public class Noticia {

	private String id;			// Id de noticia, es la clave de la tabla, se inicializa en el constructor con un UUID aleatorio
	private String titular;		// El texto que forma el titular de la noticia
	private String descripcion;	// La descripción de la noticia
	private String enlace;		// Enlace a la fuente de la noticia
	private String autor;		// login del autor de la publicación de la noticia
	private String email;		// email del usuario que da de alta la noticia
	private Map<String, Comentario> comentarios;	// Hasmap de comentrios indexado por una clave
	
	// Constructor de la noticia, pasamos todos los campos excepto el Id que se genera sobre la marcha
	public Noticia(String autor, String email, String titular, String descripcion, String enlace) {
		
		// Valor aleatorio para el Id
		this.id = java.util.UUID.randomUUID().toString();
		
		// Resto de los campos que se han pasado como parámetro
		this.autor = autor;		
		this.email = email;
		this.titular = titular;
		this.descripcion = descripcion;
		this.enlace = enlace;
		
		// Inicializamos el Hasmap
		this.comentarios = new HashMap<String, Comentario>();
	}

	// Borramos un comentario a partir de su clave
	public void deleteComentario(String key) {
		this.comentarios.remove(key);
	}
	
	// Añadimos un comentario, se pasa como argumento el propio comentario
	// el valor del Key de la estructura Hashmap es el campo Id del propio comentario
	public String addComentario(Comentario comentario) {
		this.comentarios.put(comentario.getId(), comentario);
		return (id);
	}

	// Obtenemos los comentaros como una colección simple con todos los valores 
	// Este método lo usamos para devolver una estructura de datos simple sobre
	// La que podemos iterar fácilmente en las páginas jsp
	public Collection<Comentario> getComentariosCollection() {
		return comentarios.values();
	}

	// Getters y Setters de los campos

	public Integer getNumComentarios() {
		return comentarios.size();
	}

	public String getTitular() {
		return titular;
	}

	public void setTitular(String titular) {
		this.titular = titular;
	}

	public String getDescripcion() {
		return descripcion;
	}

	public void setDescripcion(String descripcion) {
		this.descripcion = descripcion;
	}

	public String getEnlace() {
		return enlace;
	}

	public void setEnlace(String enlace) {
		this.enlace = enlace;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getAutor() {
		return autor;
	}

	public void setAutor(String autor) {
		this.autor = autor;
	}

	public Map<String, Comentario> getComentarios() {
		return comentarios;
	}

	public void setComentarios(Map<String, Comentario> comentarios) {
		this.comentarios = comentarios;
	}

	public String getEmail() {
		return email;
	}

	public void setEmail(String email) {
		this.email = email;
	}

	// Metodo toString para depuración, devuelve una noticia como cadena
	// Los comentarios correspondientes se recorren y también es invocado su toString correspondiente
	// para mostrar sus valores
	public String toString() {

		// Usamos un Stringbuilder para ir contatenando
		StringBuilder builder = new StringBuilder();
		
		// Añadimos los campos
		builder.append("Noticia [id=" + id + ", autor=" + autor + ", email=" + email + ", titular="
				+ titular + ", descripcion=" + descripcion + ", enlace="
				+ enlace + "]");

		builder.append("[");
		// Recorremos las claves del hashmap
		for (String clave : comentarios.keySet()) {
			// Obtengo el comentario a partir de su clave
			Comentario comentario = this.comentarios.get(clave);
			builder.append("\r\ncomentario: clave:" + clave + " " + comentario);
		}
		builder.append("]");

		return (builder.toString());

	}
}
