/*
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * Autor:Enrique Mengíbar Vázquez
 * Fecha: Enero 2012 
 * 
 * Description: Comando que es invocado desde la vista de inicio, uarda en una variable 
 * de sesión el login del usuario, da acceso a la aplicación de pruebas es el command
 * de entrada a la aplicación
 * 
 */

package org.sofp.test.comandos;

import javax.servlet.ServletException;
import javax.servlet.jsp.PageContext;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.sofp.ambito.Contexto;
import org.sofp.comandos.Command;
import org.sofp.config.ConfigComando;
import org.sofp.config.ConfigVista;
import org.sofp.excepciones.CommandNoValidadoException;
import org.sofp.excepciones.VistaNoEncontradaException;
import org.sofp.forms.FormBean;
import org.sofp.test.basededatos.Basededatos;
import org.sofp.test.basededatos.Constantes;
import org.sofp.test.formbeans.LoginFormbean;

// Implementamos la interface Command
public final class BienvenidaCmd implements Command {

	// Utilizamos un logger proporcionado por Apache Commons para dejar una
	// traza de la ejecución en el log del servidor de aplicaciones
	private static final Log log = LogFactory.getLog(BienvenidaCmd.class);

	// Método de ejecución del objeto COmmand
	public ConfigVista ejecutar(ConfigComando config, FormBean formbean, Contexto commandContext) throws VistaNoEncontradaException, ServletException {

		/*
		 * Este command es la entrada a la aplicación, comenzamos creando la BD
		 * y guardándola en una variable de aplicación prviamente comprovamos si
		 * la variable ya existe, puede que el comando se haya ejecutado en una
		 * sesión diferente y la base de datos ya esté creada
		 */

		/*
		 * Obtenemos la estructura de la base de datos de una variable de
		 * aplicación, si no existe previamente obtendremos un valor nulo
		 * significará que se trata de la primera ejecución del comando
		 */
		Basededatos bd = (Basededatos) commandContext.getVariableAmbito(Constantes.BASEDEDATOS, PageContext.APPLICATION_SCOPE);

		/*
		 * Si la bd es nula es que es la primera ejecuión y no existe reamos la
		 * bd, el constructor se encarga de poblarla a partir del fichero de
		 * propiedades
		 */
		if (bd == null)
			bd = new Basededatos();

		// Guardamos en una variable de sesión el nombre del usuario
		LoginFormbean loginFormbean = (LoginFormbean) formbean;
		commandContext.setVariableAmbito(Constantes.USUARIO, loginFormbean, PageContext.SESSION_SCOPE);

		// Guardamos en una variable de sesión la bd completa, para poder compartirla entre las distintas sesiones
		commandContext.setVariableAmbito(Constantes.BASEDEDATOS, bd, PageContext.APPLICATION_SCOPE);
		
		// Obtenemos el valor de la vista correspondiente al resultadoejecución ok en este comando
		ConfigVista vista = config.obtenerVista(Constantes.VISTAOK);

		// Devolvemos la vista
		return (vista);
	}

	// No realizamos ninguna validación en el servidor
	public void validar(FormBean formulario, Contexto commandContext) throws CommandNoValidadoException {
	}
}
