/*
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * Autor:Enrique Mengíbar Vázquez
 * Fecha: Enero 2012 
 * 
 * Description: Comando que es invocado desde la vista de inicio, uarda en una variable 
 * de sesión el login del usuario, da acceso a la aplicación de pruebas es el command
 * de entrada a la aplicación
 * 
 */

package org.sofp.test.comandos;

import javax.servlet.ServletException;
import javax.servlet.jsp.PageContext;

import org.sofp.ambito.Contexto;
import org.sofp.comandos.Command;
import org.sofp.config.ConfigComando;
import org.sofp.config.ConfigVista;
import org.sofp.excepciones.CommandNoValidadoException;
import org.sofp.excepciones.VistaNoEncontradaException;
import org.sofp.forms.FormBean;
import org.sofp.test.basededatos.Basededatos;
import org.sofp.test.basededatos.Comentario;
import org.sofp.test.basededatos.Constantes;
import org.sofp.test.basededatos.Noticia;
import org.sofp.test.formbeans.ComentarioFormbean;
import org.sofp.test.formbeans.LoginFormbean;

// Implementamos el comando
public final class ComentarioAnadirCmd implements Command {

	public ConfigVista ejecutar(ConfigComando conf, FormBean formbean, Contexto commandContext) throws VistaNoEncontradaException, ServletException {

		// Recuperamos los datos del comentario que nos llega desde la vista en un formbean
		ComentarioFormbean comentarioFormbean = (ComentarioFormbean) formbean;
		
		// Obtenemos el id de la noticia a la que queremos añadir el comentario y que se ha pasado desde 
		// la vista junto con el texto del comentario
		String idNoticia=comentarioFormbean.getIdNoticia();

		// Recuperamos la bd de la variable de aplicación para operar con ella
		Basededatos bd = (Basededatos) commandContext.getVariableAmbito(Constantes.BASEDEDATOS, PageContext.APPLICATION_SCOPE);

		// Obtenemos la noticia a partir del id de la noticia que hemos pasado como parámetro
		Noticia noticia = bd.getNoticia(idNoticia);
		
		// Obtenemos el login del usuario a partir de la variable de sessión donde lo almacenamos en el inicio
		LoginFormbean loginFormbean = (LoginFormbean) commandContext.getVariableAmbito(Constantes.USUARIO, PageContext.SESSION_SCOPE);
		
		// Obtenemos el comentario del formbean
		String comentario=comentarioFormbean.getComentario();
		
		// Añadimos la noticia
		noticia.addComentario(new Comentario(loginFormbean.getUsuario(), comentario));

		// Para informar al usuario que el comentario ha sido dado de alta
		// guardamos en una variable de ámbito request el titular
		commandContext.setVariableAmbito(Constantes.MENSAJE, comentario, PageContext.REQUEST_SCOPE);

		// Pasamos a la vista el id de la noticia a la que pertenece el comentario
		// esto lo necesitaremos en la vista para construir un vinculo a la lista de noticias
		commandContext.setVariableAmbito(Constantes.IDNOTICIA, idNoticia, PageContext.REQUEST_SCOPE);
		
		ConfigVista vista = conf.obtenerVista(Constantes.VISTAOK);
		
		// Creamos una vaiable que será recuperada en la vista con el titular de la noticia añadida
		commandContext.setVariableAmbito(Constantes.MENSAJE, comentario, PageContext.REQUEST_SCOPE);

		return (vista);
	}

	// Realizamos una validación simple, comprobamos que el campo contenido no está vacio
	public void validar(FormBean formulario, Contexto commandContext) throws CommandNoValidadoException {

		ComentarioFormbean comentario = (ComentarioFormbean) formulario;
		if (comentario.getComentario() == null || comentario.getComentario().length() == 0)
			throw new CommandNoValidadoException("comentario", "comentario", "El contenido del comentario no puede estar vacio");

	}
}
