/*
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * Autor:Enrique Mengíbar Vázquez
 * Fecha: Enero 2012 
 * 
 * Description: Borra un comentario asociado a una noticia, sólo se permite borrar aquellos comentarios que ha publicado el usuario
 * 
 */

package org.sofp.test.comandos;

import java.util.Map;

import javax.servlet.ServletException;
import javax.servlet.jsp.PageContext;

import org.sofp.ambito.Contexto;
import org.sofp.comandos.Command;
import org.sofp.config.ConfigComando;
import org.sofp.config.ConfigVista;
import org.sofp.excepciones.CommandNoValidadoException;
import org.sofp.excepciones.VistaNoEncontradaException;
import org.sofp.forms.FormBean;
import org.sofp.test.basededatos.Basededatos;
import org.sofp.test.basededatos.Comentario;
import org.sofp.test.basededatos.Constantes;
import org.sofp.test.basededatos.Noticia;
import org.sofp.test.formbeans.IdComentarioFormbean;
import org.sofp.test.formbeans.LoginFormbean;

public final class ComentarioBorrarCmd implements Command {

	public ConfigVista ejecutar(ConfigComando conf, FormBean formbean, Contexto commandContext) throws VistaNoEncontradaException, ServletException {

		// Recuperamos los datos del comentario a borrar que nos llega desde la vista en un formbean
		IdComentarioFormbean comentarioFormbean = (IdComentarioFormbean) formbean;
		
		// Obtenemos el ide del comentario y la noticia a la que pertenece
		String idComentario = comentarioFormbean.getIdComentario();
		String idNoticia = comentarioFormbean.getIdNoticia();
		
		// Recuperamos la bd de la variable de aplicación para operar con ella
		Basededatos bd = (Basededatos) commandContext.getVariableAmbito(Constantes.BASEDEDATOS, PageContext.APPLICATION_SCOPE);

		// Obtenemos el usuario que tenemos almacenado en una variable de sesion
		LoginFormbean loginFormbean = (LoginFormbean) commandContext.getVariableAmbito(Constantes.USUARIO, PageContext.SESSION_SCOPE);

		// Obtenemos el usuario de la sesion
		String usuarioSesion=loginFormbean.getUsuario();

		// Recuperamos la noticia de la BD a partir de su id, recuperado del formbean
		Noticia noticia = bd.getNoticia(idNoticia);

		// Obtenemos los comentarios de la noticia
		Map<String, Comentario> comentarios = noticia.getComentarios();
		
		// Obtenemos el comentario sobre el que ha actuado el usuario a partir del id del comentario
		Comentario comentario = comentarios.get(idComentario);

		ConfigVista vista = null;
		
		// Comprobamos si el usuario que ha iniciado sesion coincide con el asociado al comentario
		if (usuarioSesion.equalsIgnoreCase(comentario.getAutor())) {
			
			// Borramos la noticia
			noticia.deleteComentario(idComentario);
			
			// Creamos una vaiable que será recuperada en la vista con el titular de la noticia borrada
			commandContext.setVariableAmbito(Constantes.MENSAJE, comentario.getComentario(), PageContext.REQUEST_SCOPE);
			
			// retornamos a la vista asociada a respuesta sin error
			vista = conf.obtenerVista(Constantes.VISTAOK);
		} else {
			
			// Para informar al usuario que el comentario no se ha podido eliminar
			// guardamos en una variable de ámbito request el propietario para informar al usuario
			commandContext.setVariableAmbito(Constantes.MENSAJE, comentario.getAutor(), PageContext.REQUEST_SCOPE);
			
			// retornamos a la vista que informa que se ha producido un error
			vista = conf.obtenerVista(Constantes.VISTAERROR);
		}
		
		// Pasamos a la vista el id de la noticia a la que pertenece el comentario
		// esto lo necesitaremos en la vista para construir un vinculo a la lista de noticias
		commandContext.setVariableAmbito(Constantes.IDNOTICIA, idNoticia, PageContext.REQUEST_SCOPE);

		return (vista);
	}

	public void validar(FormBean formulario, Contexto commandContext) throws CommandNoValidadoException {
	}
}