/*
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * Autor:Enrique Mengíbar Vázquez
 * Fecha: Enero 2012 
 * 
 * Description: Este comando es invocado desde la vista NoticiasMostrar, recoge los valores de
 * cada campo de la noticia que se desea dar de alta desde el formulario HTML de la vista.
 * 
 */

package org.sofp.test.comandos;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import javax.servlet.ServletException;
import javax.servlet.jsp.PageContext;

import org.sofp.ambito.Contexto;
import org.sofp.comandos.Command;
import org.sofp.config.ConfigComando;
import org.sofp.config.ConfigVista;
import org.sofp.excepciones.CommandNoValidadoException;
import org.sofp.excepciones.VistaNoEncontradaException;
import org.sofp.forms.FormBean;
import org.sofp.test.basededatos.Basededatos;
import org.sofp.test.basededatos.Constantes;
import org.sofp.test.basededatos.Noticia;
import org.sofp.test.formbeans.NoticiaFormbean;

public final class NoticiaAnadirCmd implements Command {

	// Expresión regular para validar el formato de una dirección de email
	private static final String PATRON_EMAIL = "^[_A-Za-z0-9-]+(\\.[_A-Za-z0-9-]+)*@[A-Za-z0-9]+(\\.[A-Za-z0-9]+)*(\\.[A-Za-z]{2,})$";

	public ConfigVista ejecutar(ConfigComando config, FormBean formbean, Contexto commandContext) throws VistaNoEncontradaException, ServletException {

		// Recuperamos los datos de la noticia dada de alta que nos llega desde la vista en un formbean
		NoticiaFormbean noticiaFormbean = (NoticiaFormbean) formbean;

		// Recuperamos la bd de la variable de aplicación para operar con ella
		Basededatos bd = (Basededatos) commandContext.getVariableAmbito(Constantes.BASEDEDATOS, PageContext.APPLICATION_SCOPE);		

		// Recuperamos los valores del formbean campo a campo
		String autor=noticiaFormbean.autor;
		String email=noticiaFormbean.email;
		String titular=noticiaFormbean.titular;
		String descripcion=noticiaFormbean.descripcion;
		String enlace=noticiaFormbean.enlace;
		
		// Añadimos una nueva noticia,
		bd.addNoticia(new Noticia(autor, email, titular, descripcion, enlace));

		// Para informar al usuario que la noticia se ha dado de alta
		// guardamos en una variable de ámbito request el titular
		commandContext.setVariableAmbito(Constantes.MENSAJE, titular, PageContext.REQUEST_SCOPE);
		
		// Obtenemos el valor de la vista correspondiente al resultadoejecución ok en este comando
		ConfigVista vista = config.obtenerVista(Constantes.VISTAOK);

		// Devolvemos la vista
		return (vista);
	}

	/* Realizamos una validación en el lado del servidor, la validación es previa a la ejecución del comando
	 * comprobamos que los campos tengan contenido y posteriormente realizamos una validación mas compleja,
	 * por medio deuna expresión regular, comprobamos que el campo email corresponda con una dirección de 
	 * correo bien formada
	 */
	public void validar(FormBean formbean, Contexto commandContext) throws CommandNoValidadoException {
		
		// Recuperamos los datos de la noticia dada de alta que nos llega desde la vista en un formbean
		NoticiaFormbean noticiaFormbean = (NoticiaFormbean) formbean;

		// Iremos concatenando sobre las variables campo y los nombres de los campos y la descripción de cada error
		// que encontremos
		String campo = "";
		String mensaje = "";

		// Concatenamos sobre la variable campo el nombre del campo que es nulo o vacio
		campo = (noticiaFormbean.getAutor() == null || noticiaFormbean.getAutor().isEmpty()) ? "Autor, " : "";
		campo += (noticiaFormbean.getEmail() == null || noticiaFormbean.getAutor().isEmpty()) ? "Email, " : "";
		campo += (noticiaFormbean.getTitular() == null || noticiaFormbean.getAutor().isEmpty()) ? "Titular, " : "";
		campo += (noticiaFormbean.getDescripcion() == null || noticiaFormbean.getAutor().isEmpty()) ? "Descripción, " : "";
		campo += (noticiaFormbean.getEnlace() == null || noticiaFormbean.getAutor().isEmpty()) ? "Enlace " : "";

		// Si existen campos con valores nulos, usamos un mensaje genérico para avisar al usuario del error
		if (campo.length() > 0)
			mensaje += "Todos los campos del formulario Noticia son requeridos, ";

		// Si no se puede validar el correo también contabilizamos un error 
		if (validaCorreo(noticiaFormbean.getEmail()) == false) {
			campo += "Email ";
			mensaje += "el campo email no está bién formado";
		}

		// Si se produjo algún error lanzamos una excepción que será capturada por el Application Controller
		// se mostrará al usuario una página de error con un aviso
		if (campo.length() > 0)
			throw new CommandNoValidadoException(campo, "Noticia", mensaje);
	}

	// Valida una dirección de correo mediante una expresión regular que describe el formato correcto de un email
	private boolean validaCorreo(String email) {
		
		// Si el email está vacio devolvemos un valor false sin hacer ninguna comprobación
		if (email==null || email.isEmpty() || email.length()==0)
			return false;

		// Comprobamos si el email concurerda con la empresión regular definida para validar direcciones de correos
		Pattern p = Pattern.compile(PATRON_EMAIL);
		Matcher m = p.matcher(email);
		return m.matches();
	}
}
