/*
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * Autor:Enrique Mengíbar Vázquez
 * Fecha: Enero 2012 
 * 
 * Description: Este comando es invocado desde la vista NoticiasMostrar, recoge el valor de una noticia
 * que el usuario ha seleccinado para borrar. Si coincide el usuario de la sesión con el usuario que ha 
 * publicado la noticia se realizada el borrado, en caso contrario se direcciona a una vista de error
 */

package org.sofp.test.comandos;

import javax.servlet.ServletException;
import javax.servlet.jsp.PageContext;

import org.sofp.ambito.Contexto;
import org.sofp.comandos.Command;
import org.sofp.config.ConfigComando;
import org.sofp.config.ConfigVista;
import org.sofp.excepciones.CommandNoValidadoException;
import org.sofp.excepciones.VistaNoEncontradaException;
import org.sofp.forms.FormBean;
import org.sofp.test.basededatos.Basededatos;
import org.sofp.test.basededatos.Constantes;
import org.sofp.test.basededatos.Noticia;

import org.sofp.test.formbeans.IdNoticiaFormbean;
import org.sofp.test.formbeans.LoginFormbean;

public final class NoticiaBorrarCmd implements Command {

	public ConfigVista ejecutar(ConfigComando config, FormBean formbean, Contexto commandContext) throws VistaNoEncontradaException, ServletException {

		// Recuperamos la bd de la variable de aplicación para operar con ella
		Basededatos bd = (Basededatos) commandContext.getVariableAmbito(Constantes.BASEDEDATOS, PageContext.APPLICATION_SCOPE);

		// obtenemos el identificador de la noticia
		IdNoticiaFormbean idNoticiaFormbean = (IdNoticiaFormbean) formbean;
		
		// Obtenemos la noticia usando como indice el identificador de la noticia que se ha pasado como parámetro desde la vista
		Noticia noticia = bd.getNoticia(idNoticiaFormbean.getIdNoticia());
	
		// Obtenemos el usuario que tenemos almacenado en una variable de sesion
		LoginFormbean loginFormbean = (LoginFormbean) commandContext.getVariableAmbito(Constantes.USUARIO, PageContext.SESSION_SCOPE);

		// Solo permitimos que las noticias sean eliminadas por aquellos usuarios que las han creado
		// comparamos el usuario que ha publicado la noticia frente al usuario
		// que ha iniciado sesión, si no coinciden redireccionamos a una vista de error
		
		ConfigVista vista=null;
		
		String propietarioNoticia=noticia.getAutor();
		
		// Comprobamos si los usuarios coinciden
		if (loginFormbean.getUsuario().equalsIgnoreCase(propietarioNoticia)) {
			
			// Hay coincidencia, por lo tanto, borramos la noticia
			bd.deleteNoticia(idNoticiaFormbean.getIdNoticia());
			
			commandContext.setVariableAmbito(Constantes.MENSAJE, noticia.getTitular(), PageContext.REQUEST_SCOPE);
			
			// Asignamos un valor correcto a la vista de retorno
			// Obtenemos el valor de la vista correspondiente al resultadoejecución ok en este comando
			vista = config.obtenerVista(Constantes.VISTAOK);
			
		} else {
			// en caso contrario, devolvemos un mensaje de error y un mensaje al usuario
			vista = config.obtenerVista(Constantes.VISTAERROR);
			
			// Para informar al usuario que la noticia no se ha podido eliminar
			// guardamos en una variable de ámbito request el propietario para informar al usuario
			commandContext.setVariableAmbito(Constantes.MENSAJE, propietarioNoticia, PageContext.REQUEST_SCOPE);
		}
		
		return (vista);
	}

	public void validar(FormBean formulario, Contexto commandContext) throws CommandNoValidadoException {
	}
}