

//TODO si el fichero de conf no contiene referencias a mensajes (fichero antiguo de la pec3), se buscan de todas formas y al intentar cargar los properties da un error

/**
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * @author      Enrique Mengíbar Vázquez 
 * @version     1.0    
 * 
 */

package org.sofp;

import java.io.IOException;
import java.util.Locale;
import java.util.Map;

import javax.servlet.ServletException;
import javax.servlet.jsp.PageContext;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.sofp.ambito.Contexto;

import org.sofp.comandos.Command;
import org.sofp.config.ConfigComando;
import org.sofp.config.ConfigLocale;
import org.sofp.config.ConfigVista;
import org.sofp.config.ConfiguracionGlobal;
import org.sofp.excepciones.CampoNoEncontradoExcepcion;
import org.sofp.excepciones.CommandIncompletoException;
import org.sofp.excepciones.CommandNoEncontradoException;
import org.sofp.excepciones.CommandNoValidadoException;
import org.sofp.excepciones.FormularioNoEncontradoExcepcion;
import org.sofp.excepciones.VistaNoEncontradaException;
import org.sofp.forms.FormBean;

/**
 * Front Controller, hereda de la clase Servlet del sistema y mediante la configuración del 
 * descriptor de despliegue captura todas las peticiones que se hacen según un determinado 
 * formato de url que codifica el nombre del comando a ejecutar
 * 
 * @author Enrique Mengíbar Vázquez
 *
 */
public class ApplicationController {

	private static final Log log = LogFactory.getLog(ApplicationController.class);

	// Configuración global, se inicia en el constructor
	ConfiguracionGlobal configuracion;

	// Contexto del servlet
	Contexto commandContext;

	// Constructor, inicializamos la configuración y los objetos request y
	// response
	public ApplicationController(Contexto commandContext) throws IOException, ServletException {
		
		// Valores de configuración, contiene el resultado de parsear el fichero
		// de configuración
		this.commandContext = commandContext;

		// Intentamos recuperar la configuración global de una variable de aplicación
		configuracion = (ConfiguracionGlobal) commandContext.getVariableAmbito(
				Constantes.CONFIG, PageContext.APPLICATION_SCOPE);

		// La variable de configuración existe de una ejecución anterior del servlet en una sesión diferente
		if (configuracion != null) {
			log.info("Recuperada configuración del entorno de aplicación");
		} else {
			// Si la variableno exist es que se trata de la primera ejecución del servlet
			log.info("Creando configuración del entorno de aplicación");
			configuracion = new ConfiguracionGlobal();

			// Inicializamos la configuración a partir del fichero de reglas de digester
			// y el fichero de configuración de la aplicación
			configuracion.parsearValoresConfiguracion(Constantes.REGLASDIGESTER, Constantes.FICHEROCONFIGURACION);
			
			// Guardamos el objeto configuración en una variable de aplicación, para que pueda compartirse entre
			// todas las distintas sesiones de la misma aplicación
			commandContext.setVariableAmbito(Constantes.CONFIG, configuracion,PageContext.APPLICATION_SCOPE);
			log.info("Creanda configuración y almacenáda en el entorno de aplicación");
		}

		// Recuperamos del contexto del servlet la configuracion de locale del navegador como 
		// configuración predeterminada en caso de que no se especifique en el fichero de configuración global
		Locale localeBrowser = commandContext.getRequest().getLocale();

		ConfigLocale mapaLocale = configuracion.getMapLocale();
		
		if (mapaLocale != null) {

			// Obtenemos la configuración del locale que se definio en el
			// fichero de configuración
			String localeConfiguracion = mapaLocale.getLocalePredeterminado();

			// Mostramos el valor del locale del fichero de configuración
			log.info("locale en fichero de configuracion: "
					+ localeConfiguracion);

			// Cargamos los ficheros de recursos correspondientes
			// Pasamos como parámtro el locale del navegador y el especificado
			// en el fichero de configuración. En caso de que el locale 
			// del fichero de configuración no se haya definido, se tomará
			// como prederterminado el del navegador
			configuracion.cargarFicherosRecursos(localeBrowser,	localeConfiguracion);
		}

	}

/**
 *  A partir del path de la petición realizada al Front Controller se extrae el nombre del 
 *  comando, se localizan los datos del comando en la configuración y se realiza la ejecución 
 *  del comando la redirección a la vista correspondiente. los path tienen la forma 
 *  siguiente: /command/comando donde command está definido en el web.xml para mapearse a 
 *  nuestro servlet-Front Controller y comando es el nombre del comando que queremos ejecutar
 * @throws ServletException Excepción lanzada en caso de error durante el proceso
 * @throws java.io.IOException Excepción de entrada salida lanzada en caso de error durante el proceso
 */
	public void manejadorComandosVistas() throws ServletException,
	java.io.IOException {

		String paginaVista = null;

		// Recuperamos de request la información del Path
		String path = commandContext.getRequest().getPathInfo();
		
		// Obtenemos el comando a ejectar a partir del path
		String nombreComando = ObtenerNombreComando(path);

		// Recuperamos el formulario e instanciamos su clase FormBean
		try {

			// Accedemos al mapa de comandos de la configuración
			Map<String, ConfigComando> mapComandos = configuracion.getMapComandos();

			//Obtenemos el comando correspondiente de la configuración
			ConfigComando comando = mapComandos.get("/" + nombreComando);

			// Si no pudimos recuperar el comando lanzamos una excepción 
			if (comando == null)
				throw new CommandIncompletoException(nombreComando);

			// Instanciamos dinámicamente el comando
			Command instanciaComando = instanciarComando(comando);

			// Instanciamos el formbean apropiado para recuperar los datos de la petición request
			FormBean formBean = comando.instanciaFormBean(commandContext, configuracion.getMapFormularios());

			// Poblamos el formBean a partir de los valores del formulario HTML que recuperamos del objeto request
			formBean.poblarClaseFormulario(commandContext);

			// Iniciamos la validación del comando a partir de los datos de su formBean
			// en caso de no sperarse la validación se lanzará una excepción
			// que será propagada hacia arriba en la pila de valores
			instanciaComando.validar(formBean, commandContext);

			// Ejecutamos el comando, la ejecución nos devuelve la vista a la
			// que debemos redirigir
			ConfigVista vista = instanciaComando.ejecutar(comando, formBean, commandContext);
			
			// Guardamos la dirección de la página a la que vamos a redirigir
			paginaVista = vista.getDireccion();

			// a contnuación, capturamos todas las posibles excepciones que se hayan podido producir
			// se redireccionará a una vista genérica que traslada el mensaje de error al usuario
		} catch (VistaNoEncontradaException e) {
			paginaVista = tratarExcepcionError(e);
		} catch (FormularioNoEncontradoExcepcion e) {
			paginaVista = tratarExcepcionError(e);
		} catch (CommandNoEncontradoException e) {
			paginaVista = tratarExcepcionError(e);
		} catch (CommandIncompletoException e) {
			paginaVista = tratarExcepcionError(e);
		} catch (ClassNotFoundException e) {
			paginaVista = tratarExcepcionError(e);
		} catch (CampoNoEncontradoExcepcion e) {
			paginaVista = tratarExcepcionError(e);
		} catch (IllegalArgumentException e) {
			paginaVista = tratarExcepcionError(e);
		} catch (CommandNoValidadoException e) {
			paginaVista = tratarExcepcionError(e);
		} catch (Exception e) {
			e.printStackTrace();
		}

		// Redireccionamos al a correspondiente vista
		commandContext.forward(paginaVista);
	}

	/**
	 * Obtenemos el nombre del comando a patir del path en la url que forma parte de la petición
	 * @param path Path de la petición, es la URL sin el dominio
	 * @return Nombre del comando extraido a partir del path
	 */
	private String ObtenerNombreComando(String path) {

		// No tenemos en cuenta la barra inicial
		String nombreComando = path.startsWith("/") ? path.substring(1) : path;

		// Comprobamos si existe alguna barra mas
		int posicionBarra = nombreComando.indexOf("/");
		if (posicionBarra != -1)
			// El nombre del comando será la parte final, usando la barra como separador
			nombreComando = nombreComando.substring(0, posicionBarra);

		// devolvemos el nombre del comando
		return nombreComando;

	}

	/**
	 * Instanciamos dinámicamente la clase asociada al comando a ejecutar
	 * @param comando Información del comando obtenida de la configuración general de la aplicación
	 * @return Obj Objeto de tipo command instanciado
	 * @throws ClassNotFoundException Si la clase no se encuentra se propaga la correspondiente excepción
	 * @throws InstantiationException Si la clase no se pudo instanciar se propaga la correspondiente excepción
	 * @throws IllegalAccessException Si se produjo un acceso no legal a los miembros de la clase se propaga la correspondiente excepción
	 */
	private Command instanciarComando(ConfigComando comando)
			throws ClassNotFoundException, InstantiationException,
			IllegalAccessException {

		// Clase genérica
		Class claseComando = null;

		// Obtenem os el nombre de la clase asociado al comando
		String nombreClaseComando = comando.getClase();

		// Definimos la clase dinámicamente a partir de su nombre
		claseComando = Class.forName(nombreClaseComando);
		
		// Instanciamos la clase definida y creamos un objeto de dicha clase
		Object objetoComando = claseComando.newInstance();

		// Devolvemos el objeto creado, con un cast lo moldeamos a un objeto Comando
		return (Command) objetoComando;

	}

	/**
	 * Tratamos la excepeción, definimos una variable de ámbito request que contendrá
	 * el mensaje de error de la excepción y será mostrado por la vista genérica que maneja
	 * todos los mensajes de error del framework
	 * @param e Excepción que seha producido
	 * @return Mensaje que será mostrado al usuario
	 * @throws NullPointerException Excepción en caso de que la variable se declare de forma incorrecta
	 * @throws ServletException Excepción para manejar cualquier error noprevisto en la asignación de la variable
	 */
	private String tratarExcepcionError(Exception e)
			throws NullPointerException, ServletException {

		// Establecemos la variable
		commandContext.setVariableAmbito(Constantes.MENSAJE, e, PageContext.REQUEST_SCOPE);

		// Nombre de la vista genérica que mostrará el mensaje de error al usuario
		String direccionVista = Constantes.PAGINAERROR;
		
		// devolvemos la vista
		return (direccionVista);
	}

}
