//TODO si no hay ficheros de recursos en el properties de configuracion, intenta cargar un fichero nulo o algo así y casca

/**
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * @author      Enrique Mengíbar Vázquez 
 * @version     1.0    
 * 
 */

package org.sofp;

import java.io.IOException;

import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import org.sofp.ambito.Contexto;

/**
 * Front Controller, hereda de la clase Servlet del sistema y mediante la configuración del 
 * descriptor de despliegue captura todas las peticiones que se hacen según un determinado 
 * formato de url que codifica el nombre del comando a ejecutar
 * 
 * @author Enrique Mengíbar Vázquez 
 * 
 */
public class FrontController extends HttpServlet {
	private static final Log log = LogFactory.getLog(FrontController.class);

	private static final long serialVersionUID = 1L;

	// el Application Controller es el encargado de realizar la resolución de la
	// petición entrante al comando apropiado, la posterior invocación del comando y finalmente,
	// en función de la lógica de ejecución que se haya llevado a cabo en el comando, se realiza
	// la entrega del control a la vista apropiada.
	ApplicationController applicationController;

	// Initializa el servle.  En la inicialización parseamos el fichero de configuración 
	// y almacenamos la configuración global en la variable valoresConfiguracion
	public void init() throws ServletException {
		// Mostramos un mensaje de información en el log
		log.info("Iniciando Servlet - FrontController");
	}

	// Destruye el servlet
	public void destroy() {
		// Mostramos un mensaje de información en el log
		log.info("Destruyendo Servlet - FrontController");
	}

	// Constructor del servlet
	public FrontController() {
	}

	// Se invoca si el formulario pasa los valores por el método Get, procesamos
	// la petición en un método diferente, para poder compartirlo la lógica 
	// entre el método Get y el Post
	protected void doGet(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {

		// Invocamos a doPost, el tratamiento será el mismo para los Get y Post
		doPost(request, response);
	}
	
	/**
	 * Se invoca si el formulario pasa los valores por el método Postt, procesamos la petición
	 * es un método protected de uso interno, no pertenece al API del framework
	 */
	protected void doPost(HttpServletRequest request,
			HttpServletResponse response) throws ServletException, IOException {

		// Invocamos al método interno que realiza el proceso de lapetición
		// como paŕamtros le pasamos una referencia al contexto del propio
		// servlet y los objetos request y response asociados a la petición
		ServletContext context = this.getServletContext();
		procesarPeticion(context, request, response);
	}

	/**
	* Método para procesar la petición recibe como parámetro el contexto del servlet y los objetos
	* request y response asociados a la petición
	*/
	protected void procesarPeticion(ServletContext contex,
			HttpServletRequest request, HttpServletResponse response)
					throws ServletException, java.io.IOException {

		// Iniciamos el contexto, pasamos como parámtros al contructor
		// una referencia al contexto del propio servlet y los objetos
		// request y response de l apetición
		Contexto commandContext = new Contexto(this, request, response);

		log.info("Inicio procesar Peticion en Application Controller");

		// Instanciamos el ApplicationController y le invocamos, pasamos la 
		// configuración y los objetos request y response que proporcionan acceso a 
		// la entrada y salida del Servlet respectivamente
		applicationController = new ApplicationController(commandContext);
		
		// Invocamos al método principal del Application Controller encargado de la ejecución de los comandos
		// manejo y población automática de los formbeans
		// y redirección a las correspondientes vistas de respuesta
		applicationController.manejadorComandosVistas();

		log.info("Fin procesar Peticion en Application Controller");

	}

}
