/**
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * @author      Enrique Mengíbar Vázquez 
 * @version     1.0    
 * 
 */

package org.sofp.comandos;

import javax.servlet.ServletException;

import org.sofp.ambito.Contexto;
import org.sofp.config.ConfigComando;
import org.sofp.config.ConfigVista;
import org.sofp.excepciones.CommandNoValidadoException;
import org.sofp.excepciones.VistaNoEncontradaException;
import org.sofp.forms.FormBean;

/**
 * Interface que deben implementar todos los comandos, tiene dos métodos, uno para la 
 * ejecución y otro para la validación.
 * 
 * @author Enrique Mengíbar Vázquez 
 *
 */
public interface Command {
	
	/**
	 * Método para la ejecución del comando
	 * @param config Configuración de la aplicación
	 * @param formulario Formbean que se pasa a la vista a partir de los datos generados por la vista que lo invoca
	 * @param commandContext Contexto, para poder manejar variables de ámbito (sesion, aplicacion, request) y redirecciones
	 * @return Devuelve una referencia a una vista, dependiendo del resultado del comando
	 * @throws VistaNoEncontradaException En caso de que no se encuentre una vista y se lance una excepción se propaga
	 * @throws ServletException  En caso de que se produzca una excepción en el manejo de la referencia al servlet se propaga
	 */
	ConfigVista ejecutar(ConfigComando config, FormBean formulario,
			Contexto commandContext) throws VistaNoEncontradaException,
			ServletException;

	/** 
	 * Metodo para validar los datos de un formulario, se ejcuta previamente a la ejecución, la validación se define
	 *  mediante código Java en este método, encaso de no superarla se lanzará una excepción CommandNoValidadoException
	 *  que será propagada y capturada por el Application Controller
	 * @param formulario que se pasa a la vista a partir de los datos generados por la vista que lo invoca
	 * @param commandContext para poder manejar variables de ámbito (sesion, aplicacion, request) y redirecciones
	 * @throws CommandNoValidadoException Si la vista no se encuentra se propaga esta excepción
	 */
	void validar(FormBean formulario, Contexto commandContext)
			throws CommandNoValidadoException;
}