/**
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * @author      Enrique Mengíbar Vázquez 
 * @version     1.0    
 * 
 */

package org.sofp.config;

import java.util.HashMap;
import java.util.Locale;
import java.util.Map;
import java.util.ResourceBundle;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Representa el valor de locale en la configuración del framework SOFP
 * utilizado en la gestión de la internacionalización del framework
 * 
 * @author Enrique Mengíbar Vázquez
 *
 */
public class ConfigLocale {

	String localePredeterminado;
	private Map<String, ConfigRecursoMensajes> mapRecursoMensajes;
	private Map<String, ResourceBundle> mapRecursoBundle;

	/**
	 * Constructor, inicializa las colecciones, una de recursos ResourceBundle
	 * directamente manejable por java y la otra de tipo ConfigRecursoMensajes,
	 * con los valores leidos del fichero de configuración
	 */
	public ConfigLocale() {
		// Iniciamos el atributo que contiene los valores de configuración del
		// locale, tal y como se han
		// leido de la configuración
		this.mapRecursoMensajes = new HashMap<String, ConfigRecursoMensajes>();
		// Iniciamos el atributo que contiene directamente los recursos
		// ResourceBoundle para manejar
		// los properties de mensajes de la configuración
		this.mapRecursoBundle = new HashMap<String, ResourceBundle>();
	}

	/**
	 * Obtiene el napa de recursos de la configuración del framework
	 * 
	 * @return Mapa de recursos de la configuración del framework
	 */
	public Map<String, ConfigRecursoMensajes> getMapRecursoMensajes() {
		return mapRecursoMensajes;
	}

	/**
	 * Establece el mapa de recursos de la configuración del framework
	 * 
	 * @param mapRecursoMensajes
	 *            Mapa de recursos de la configuración del framework
	 */
	public void setMapRecursoMensajes(
			Map<String, ConfigRecursoMensajes> mapRecursoMensajes) {
		this.mapRecursoMensajes = mapRecursoMensajes;
	}

	/**
	 * Obtiene el locale predeterminado de la configuración
	 * 
	 * @return Valor del locale predeterminado de la configuración
	 */
	public String getLocalePredeterminado() {
		return localePredeterminado;
	}

	/**
	 * Establece el valor del locale predetermnado de la configuración
	 * 
	 * @param localePredeterminado
	 *            Valor del locale predeterminado de la configuración
	 */
	public void setLocalePredeterminado(String localePredeterminado) {
		this.localePredeterminado = localePredeterminado;
	}

	/**
	 * Obtiene el mapa de recursos ResourceBundle para manejos de los properties
	 * de configuración
	 * 
	 * @return Mapa de recursos ResourceBundle para manejar por la configuración
	 */
	public Map<String, ResourceBundle> getMapRecursoMensajesBundle() {
		return mapRecursoBundle;
	}

	/**
	 * Estableceel valor del mapa de recursos ResourceBundle de los properties
	 * de configuración
	 * 
	 * @param mapRecursoMensajesDeVerdad
	 *            Valor del mapa de recursos ResourceBundle de manejo de los
	 *            properties de configuración
	 */
	public void setMapRecursoBundle(
			Map<String, ResourceBundle> mapRecursoMensajesDeVerdad) {
		this.mapRecursoBundle = mapRecursoMensajesDeVerdad;
	}

	/**
	 * Añade un nuevo mapa de recursos a la configuración
	 * 
	 * @param recursoMensajes
	 *            Mapa de recursos de la configuración
	 */
	public void addRecursoMensajes(ConfigRecursoMensajes recursoMensajes) {
		mapRecursoMensajes.put(recursoMensajes.getNombre(), recursoMensajes);
	}

	/**
	 * Obtiene el mapa de recursos de la configuración ResourceBundle para el
	 * manejo de los properties
	 * 
	 * @param nombre
	 *            Nombre del recurso ResourceBundle
	 * @param recursoMensajesBundle
	 *            Recurso ResourceBundle para el manejo de los properties de
	 *            configiración
	 */
	public void addRecursoBundle(String nombre,
			ResourceBundle recursoMensajesBundle) {
		mapRecursoBundle.put(nombre, recursoMensajesBundle);
	}
}
