/**
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * @author      Enrique Mengíbar Vázquez 
 * @version     1.0    
 * 
 */

package org.sofp.excepciones;

import javax.servlet.ServletException;

/**
 * Excepción utilizada en el manejo de la inicialización de la configuración
 * Se lanza en caso de que la definición de un comando esté incompleta o haya alguna inconsistencia
 * 
 * @author Enrique Mengíbar Vázquez
 *
 */
public final class CommandIncompletoException extends ServletException {

	private static final long serialVersionUID = 1L;

	/**
	 * Existe un error en la definición de un comando en la configuración de la aplicación
	 * @param nombre Nombre del comando donde se ha encontrado el error
	 * @param e Excepción
	 */
	public CommandIncompletoException(String nombre, Exception e) {
		// Obtenemos un mensaje de error personalizado o usamos el mensaje genérico de la propia
		// excepción si el nombre del campo es nulo
		super(
				(nombre == null || nombre.length() == 0) ? "El comando nulo no es válido"
						: ("El command de nombre <b>" + nombre + "</b>" + " está declarado de forma incompleta"),
				e);
	}

	/**
	 * Existe un error en la definición de un comando en la configuración de la aplicación
	 * @param nombre Nombre del comando donde se ha encontrado el error
	 */
	public CommandIncompletoException(String nombre) {
		this(nombre, null);
	}

}
