/**
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * @author      Enrique Mengíbar Vázquez 
 * @version     1.0    
 * 
 */

package org.sofp.excepciones;

import javax.servlet.ServletException;

/**
 * Excepción utilizada en el manejo de la población automática de los formBean
 * Se lanza en caso de que un comando no pueda ser localizado
 * 
 * @author Enrique Mengíbar Vázquez 
 *
 */
public final class CommandNoEncontradoException extends ServletException {

	private static final long serialVersionUID = 1L;

	/**
	 * Excepción que representa un comando que no ha podido ser localizado en la configuración
	 * @param comando Comando donde seha producido el error
	 * @param e Excpeción
	 */
	public CommandNoEncontradoException(String comando, Exception e) {
		// Obtenemos un mensaje de error personalizado o usamos el mensaje genérico de la propia
		// excepción si el nombre del campo es nulo
		super(
				(comando == null || comando.length() == 0) ? "El comando nulo no es válido"
						: ("El commando de nombre <b>" + comando + "</b>" + " no existe"),
						e);
	}

	/**
	 * Excepción que representa un comando que no ha podido ser localizado en la configuración
	 * @param comando Comando donde seha producido el error
	 */
	public CommandNoEncontradoException(String comando) {
		this(comando, null);
	}

}
