/**
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * @author      Enrique Mengíbar Vázquez 
 * @version     1.0    
 * 
 */

package org.sofp.excepciones;

import javax.servlet.ServletException;

/**
 * Excepción utilizada en el manejo de la configuración, se lanza cuando un comando
 * no puede ser encontrad, normalmente por la invocación incorrecta desde el cliente con un
 * url no válida
 * 
 * @author Enrique Mengíbar Vázquez
 */
public final class CommandNoValidadoException extends ServletException {

	private static final long serialVersionUID = 1L;

	/**
	 * Representa una excepción en la que un comando no supera la validación, la validación 
	 * se ejectua programaticamente en el método validar del comando
	 * @param comando Nombre del comando
	 * @param nombre Nombre del formbean donde se ha producido el error de validación
	 * @param mensaje Mensaje de error
	 * @param e Excepción
	 */
	public CommandNoValidadoException(String comando, String nombre,
			String mensaje, Exception e) {
		// Obtenemos un mensaje de error personalizado o usamos el mensaje genérico de la propia
		// excepción si el nombre del campo es nulo
		super(
				(nombre == null || nombre.length() == 0) ? "El comando nulo no es válido"
						: ("No se ha superado la validación en el campo <b>"
								+ comando + "</b> del formBean <b>" + nombre
								+ "</b>." + ". El mensaje de error es: <b>"
								+ mensaje + "</b>"), e);
	}

	/**
	 * Representa una excepción en la que un comando no supera la validación, la validación 
	 * se ejectua programaticamente en el método validar del comando
	 * @param comando Nombre del comando
	 * @param nombre Nombre del formbean donde se ha producido el error de validación
	 * @param mensaje Mensaje de error
	 */
	public CommandNoValidadoException(String comando, String nombre,
			String mensaje) {
		this(comando, nombre, mensaje, null);
	}

}
