/**
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * @author      Enrique Mengíbar Vázquez 
 * @version     1.0    
 * 
 */

package org.sofp.excepciones;

import javax.servlet.ServletException;

/**
 * Excepción utilizada durante la lectura de la configuración si se encuentra
 * algún problema a la hora de recuperar el formulario asociado a un comando en el proceso
 * de lecura de la configuración
 * 
 * @author Enrique Mengíbar Vázquez 
 *
 */
public final class FormularioNoEncontradoExcepcion extends ServletException {

	private static final long serialVersionUID = 1L;

	/**
	 * Descripcion: Excepción utilizada durante la lectura de la configuración, es lanzada si una
	 * formulario no se encuentra correctamente y no se puede localizar
	 *  
	 * @param nombre Nombre del formulario que no ha podido ser localizada
	 * @param e Excepción
	 */
	public FormularioNoEncontradoExcepcion(String nombre, Exception e) {
		// Obtenemos un mensaje de error personalizado o usamos el mensaje genérico de la propia
		// excepción si el nombre del campo es nulo
		super(
				(nombre == null || nombre.length() == 0) ? "Formulario nulo no es válido"
						: ("El formulario de nombre <b>" + nombre + "</b>" + " no existe"),
				e);
	}

	/**
	 * Descripcion: Excepción utilizada durante la lectura de la configuración, es lanzada si una
	 * formulario no se encuentra correctamente y no se puede localizar
	 *  
	 * @param nombre Nombre del formulario que no ha podido ser localizada
	 */
	public FormularioNoEncontradoExcepcion(String nombre) {
		this(nombre, null);
	}

}
