/**
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * @author      Enrique Mengíbar Vázquez 
 * @version     1.0    
 * 
 */

package org.sofp.excepciones;

import javax.servlet.ServletException;

/**
 * Excepción utilizada durante la navegación, es lanzada si una vista no peude ser localizada
 * La vista se propaga hacia arriba hasta que el application controller la recoge y redirecciona a una
 * vista genérica de errores donde se muestra el correspondiente mensaje de error al usuario
 * 
 * @author Enrique Mengíbar Vázquez
 *
 */
public final class VistaNoEncontradaException extends ServletException {

	private static final long serialVersionUID = 1L;

	/**
	 * Descripcion: Excepción utilizada durante la navegación, es lanzada si una
	 * vista no peude ser localizada
	 *  
	 * @param nombre Nombre de la vista que no ha podido ser localizada
	 * @param e Excepción
	 */
	public VistaNoEncontradaException(String nombre, Exception e) {
		// Obtenemos un mensaje de error personalizado o usamos el mensaje
		// genérico de la propia
		// excepción si el nombre del campo es nulo
		super(
				(nombre == null || nombre.length() == 0) ? "No se puede mostrar una vista nula"
						: ("La vista de nombre <b>" + nombre + "</b>" + " no existe"),
				e);
	}

	/**
	 * Descripcion: Excepción utilizada durante la navegación, es lanzada si una
	 * vista no peude ser localizada
	 *  
	 * @param nombre Nombre de la vista que no ha podido ser localizada
	 */
	public VistaNoEncontradaException(String nombre) {
		this(nombre, null);
	}

}
