/**
 * Universitat Oberta de Catalunya
 * Ingeniería de Informática, 2º ciclo
 * Proyecto fin de carrera- Diseño e implementación de un framework de presentación
 * 
 * @author      Enrique Mengíbar Vázquez 
 * @version     1.0    
 *
 */

package org.sofp.forms;

import java.lang.reflect.Field;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.sofp.FrontController;
import org.sofp.ambito.Contexto;
import org.sofp.excepciones.CampoNoEncontradoExcepcion;

/**
 * Clase abstracta de la que deben extender e implementar los formbeans
 * Contiene el método PoblarClaseFormulario que se utiliza para poblar automáticamente el formbean
 * a partir de los valores del formulario HTML de la vista que invoca al comando
 * el mapeo y la asignación de valores se realiza de forma automática, deben existir 
 * concordancia entre los campos del formulario HTML y los atributos del formbean correspondiente
 * 
 * @author Enrique Mengíbar Vázquez
 *
 */
public abstract class FormBean {

	// Mostramos mensajes informativos en el log, para ayudar a interpretar la traza de ejecución
	private static final Log log = LogFactory.getLog(FrontController.class);

	// Dinamicamente añadimos los atributos a un FormBean específico a partir de los 
	// campos de un formulario HTML recogidos del objeto request del servlet
	final public void poblarClaseFormulario(
			Contexto commandContext)
					throws CampoNoEncontradoExcepcion, NumberFormatException,
					IllegalArgumentException, IllegalAccessException {

		// Obtenemos dinámicamente la colección de campos de la clase del
		// formBean que	estamos manejando
		Field[] atributosFormBean = this.getClass().getDeclaredFields();

		// Recorremos la colección
		for (Field atributo : atributosFormBean) {
			// Por cada campo de la clase, tratamos de recogerlo de la entrada
			// al servlet desde un form HTML
			String nombreAtributo = atributo.getName();
			String valorForm = commandContext.getRequest().getParameter(
					nombreAtributo);
			if (valorForm == null) {
				// el atributo perteneciente al formBean no tiene equivalente en el formulario
				// Lamzamos una excepción y generamos un mensaje de error en el log
				log.error("el atributo "
						+ nombreAtributo
						+ " perteneciente al formBean no tiene equivalente en el formulario");
				throw new CampoNoEncontradoExcepcion(nombreAtributo, this
						.getClass().getName());
			} else

				// Ahora averiguamos cual es el tipo de cada campo en la
				// clase FormBean de nuestro formulario y asignamos dinamicamente el valor
				// de forma apropiada parseando desde String al tipo apropiado
				if (!valorForm.equals("")) {
					if (atributo.getType().equals(Integer.TYPE))
						atributo.set(this, Integer.parseInt(valorForm));
					else if (atributo.getType().equals(Double.TYPE))
						atributo.setDouble(this, Double.parseDouble(valorForm));
					else if (atributo.getType().equals(Boolean.TYPE))
						atributo.setBoolean(this, Boolean.parseBoolean(valorForm));
					else
						atributo.set(this, valorForm);
				}
		}
	}
}

